package com.jz.sms.chuanlan.service.impl;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.jz.sms.api.BizController;
import com.jz.sms.chuanlan.dto.CLSendFixedRequest;
import com.jz.sms.chuanlan.dto.CLSendFixedResponse;
import com.jz.sms.chuanlan.dto.CLTemplateResponse;
import com.jz.sms.chuanlan.service.ChuanLanSmsService;
import com.jz.sms.chuanlan.utils.ChuangLanSmsUtil;
import com.jz.sms.config.SMSConfig;
import com.jz.sms.dto.*;
import com.jz.sms.util.HttpUtil;
import com.jz.sms.util.Md5Util;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


@SuppressWarnings("DuplicatedCode")
@Service
public class ChuanLanSmsServiceImpl implements ChuanLanSmsService {

    private static final Logger log = LoggerFactory.getLogger(BizController.class);

    @Override
    public CLTemplateResponse createTemplate(String content, String type) throws Exception {
        log.info("进入创蓝创建短信接口模板的逻辑：{}", content);
        Map<String, Object> requestMap = new HashMap<>();
        String appId;
        String username;
        String password;
        if ("notification".equals(type)) {
            appId = "49";
            username = SMSConfig.notificationAccount;
            password = SMSConfig.notificationPassword;
        } else if ("marketing".equals(type)) {
            appId = "52";
            username = SMSConfig.marketingAccount;
            password = SMSConfig.notificationPassword;
        } else {
            // TODO 自定义异常
            throw new Exception("");
        }

        String timestamp = String.valueOf(System.currentTimeMillis() / 1000);
        String encrypt = Md5Util.encrypt(new StringBuffer(username).append(password).append(timestamp).toString());
        requestMap.put("username", username);
        requestMap.put("timestamp", timestamp);
        requestMap.put("signature", encrypt);
        requestMap.put("appid", appId);
        requestMap.put("content", content);
        log.info("请求创蓝创建短信模板的请求参数为：{}", requestMap);
        String retStr = HttpUtil.doPost(SMSConfig.addTemplate, requestMap);
        log.info("请求创蓝创建短信模板的返回数据为：{}", retStr);

        return new CLTemplateResponse();
    }

    @Override
    public CLSendFixedResponse sendByFixed(String batchId, String content, List<String> phoneList, String type) throws Exception {
        String account;
        String password;
        if ("notification".equals(type)) {
            account = SMSConfig.notificationAccount;
            password = SMSConfig.notificationPassword;
            log.info("发送短信的模式为：{通知类}");
        } else if ("marketing".equals(type)) {
            account = SMSConfig.marketingAccount;
            password = SMSConfig.marketingPassword;
            log.info("发送短信的模式为：{营销类}");
        } else {
            log.info("发送短信的模式为：{未知类型}");
            throw new Exception("123");
        }

        CLSendFixedRequest request = new CLSendFixedRequest(account, password, content, listToString(phoneList), "true", batchId);

        String requestJson = JSONObject.toJSONString(request);
        log.info("【{}】发送固定内容短信,请求上游数据为：{}", batchId, requestJson);
        String responseStr = ChuangLanSmsUtil.sendSmsByPost(SMSConfig.sendFixed, requestJson);
        log.info("【{}】发送固定内容短信,上游返回数据为：{}", batchId, requestJson);

        if (StringUtils.isBlank(responseStr)) {
            return new CLSendFixedResponse("500", "渠道同步响应为空");
        }
        CLSendFixedResponse response = JSON.parseObject(responseStr, CLSendFixedResponse.class);
        return response;
    }

    private String listToString(List<String> list) {
        String s = list.toString();
        return s;
    }

    public static void main(String[] args) {
        List<String> arr = new ArrayList<>();
        arr.add("aa,444");
        System.out.printf(arr.toString());
    }

    @Override
    public CLSendFixedResponse sendByVariable(String batchId, String content, List<String> params, String type) throws Exception {
        String account;
        String password;
        if ("notification".equals(type)) {
            account = SMSConfig.notificationAccount;
            password = SMSConfig.notificationPassword;
            log.info("发送短信的模式为：{通知类}");
        } else if ("marketing".equals(type)) {
            account = SMSConfig.marketingAccount;
            password = SMSConfig.marketingPassword;
            log.info("发送短信的模式为：{营销类}");
        } else {
            log.info("发送短信的模式为：{未知类型}");
            throw new Exception("123");
        }

        CLSendFixedRequest request = new CLSendFixedRequest(account, password, content, listToString(params), "true", batchId);

        String requestJson = JSONObject.toJSONString(request);
        log.info("【{}】发送固定内容短信,请求上游数据为：{}", batchId, requestJson);
        String responseStr = ChuangLanSmsUtil.sendSmsByPost(SMSConfig.sendFixed, requestJson);
        log.info("【{}】发送固定内容短信,上游返回数据为：{}", batchId, requestJson);

        if (StringUtils.isBlank(responseStr)) {
            return new CLSendFixedResponse("500", "渠道同步响应为空");
        }
        CLSendFixedResponse response = JSON.parseObject(responseStr, CLSendFixedResponse.class);
        return response;
    }

    @Override
    public DmHubSendResponse sendBatchByFixed(DmHubSendRequest requestDTO) {
        return null;
    }

    @Override
    public DmHubBatchSendResponse sendBatchByVariable(DmHubBatchSendRequest requestDTO) {
        return null;
    }
}
